[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- logging.Filterer: A base class for loggers and handlers which allows them to share common code.
  - logging.Handler: Handler instances dispatch logging events to specific destinations.
    - starcluster.logger.NullHandler
    - logging.StreamHandler: A handler class which writes logging records, appropriately formatted, to a stream.
      - starcluster.logger.ConsoleLogger
- Queue.Queue: Create a queue object with a given maximum size.
  - workerpool.pools.WorkerPool: WorkerPool servers two functions: It is a Queue and a master of Worker threads.
    - starcluster.threadpool.ThreadPool
- object: The most base type
  - starcluster.optcomplete.AllCompleter: Completes by listing all possible files in current directory.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - starcluster.exception.BaseException
        - starcluster.exception.AWSError: Base exception for all AWS related errors
          - starcluster.exception.AMIDoesNotExist
          - starcluster.exception.AWSUserIdRequired
          - starcluster.exception.BucketAlreadyExists
          - starcluster.exception.BucketDoesNotExist
          - starcluster.exception.EC2CertDoesNotExist
          - starcluster.exception.EC2CertRequired
          - starcluster.exception.EC2PrivateKeyDoesNotExist
          - starcluster.exception.EC2PrivateKeyRequired
          - starcluster.exception.InstanceDoesNotExist
          - starcluster.exception.InstanceNotRunning
          - starcluster.exception.InvalidBucketName
          - starcluster.exception.InvalidImageName
          - starcluster.exception.InvalidOperation
          - starcluster.exception.KeyPairDoesNotExist
          - starcluster.exception.RegionDoesNotExist
          - starcluster.exception.SecurityGroupDoesNotExist
          - starcluster.exception.SnapshotDoesNotExist
          - starcluster.exception.SpotHistoryError
          - starcluster.exception.VolumeDoesNotExist
          - starcluster.exception.ZoneDoesNotExist
        - starcluster.exception.CancelledCreateImage
        - starcluster.exception.CancelledCreateVolume
        - starcluster.exception.CancelledEBSImageCreation
        - starcluster.exception.CancelledStartRequest
        - starcluster.exception.ClusterDoesNotExist: Exception raised when user requests a running cluster that does not exist
        - starcluster.exception.ClusterExists
        - starcluster.exception.ClusterNotRunning: Exception raised when user requests a running cluster that does not exist
        - starcluster.exception.ClusterReceiptError: Raised when creating/loading a cluster receipt fails
        - starcluster.exception.ClusterTemplateDoesNotExist: Exception raised when user requests a cluster template that does not exist
        - starcluster.exception.CommandNotFound: Raised when command is not found on the system's PATH
          - starcluster.exception.RemoteCommandNotFound: Raised when command is not found on a *remote* system's PATH
        - starcluster.exception.ConfigError: Base class for all config related errors
          - starcluster.exception.ConfigHasNoSections
          - starcluster.exception.ConfigNotFound
          - starcluster.exception.ConfigSectionMissing
          - starcluster.exception.KeyNotFound
          - starcluster.exception.NoDefaultTemplateFound
          - starcluster.exception.PluginNotFound
        - starcluster.exception.ExperimentalFeature
        - starcluster.exception.IncompatibleCluster
        - starcluster.exception.InvalidDevice
        - starcluster.exception.InvalidIsoDate
        - starcluster.exception.InvalidPartition
        - starcluster.exception.PluginError: Base class for plugin errors
          - starcluster.exception.PluginLoadError: Raised when an error is encountered while loading a plugin
          - starcluster.exception.PluginSyntaxError: Raised when plugin contains syntax errors
        - starcluster.exception.SSHError: Base class for all SSH related errors
          - starcluster.exception.SSHAuthException: Raised when an ssh connection fails to authenticate
          - starcluster.exception.SSHConnectionError: Raised when ssh fails to to connect to a host (socket error)
          - starcluster.exception.SSHNoCredentialsError
        - starcluster.exception.ThreadPoolException
        - starcluster.exception.ValidationError: Base class for validation related errors
          - starcluster.exception.ClusterValidationError: Cluster validation related errors
            - starcluster.exception.IncompatibleSettings: Raised when two or more settings conflict with each other
            - starcluster.exception.InvalidCIDRSpecified: Raised when user specifies an invalid CIDR ip for permission
            - starcluster.exception.InvalidPortRange: Raised when user specifies an invalid port range for permission
            - starcluster.exception.InvalidProtocol: Raised when user specifies an invalid IP protocol for permission
            - starcluster.exception.InvalidZone: Raised when a zone has been specified that does not match the common zone of the volumes being attached
            - starcluster.exception.VolumesZoneError
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AssertionError: Assertion failed.
  - starcluster.cluster.Cluster
    - starcluster.volume.VolumeCreator: Handles creating, partitioning, and formatting a new EBS volume.
  - starcluster.clustersetup.ClusterSetup: ClusterSetup Interface
    - starcluster.clustersetup.DefaultClusterSetup: Default ClusterSetup implementation for StarCluster
    - starcluster.plugins.ipcluster.IPCluster: Starts an IPCluster on StarCluster
    - starcluster.tests.mytestplugin.SetupClass
    - starcluster.tests.mytestplugin.SetupClass2
    - starcluster.tests.mytestplugin.SetupClass3
  - starcluster.optcomplete.CmdComplete: Simple default base class implementation for a subcommand that supports command completion.
    - starcluster.commands.base.CmdBase: Base class for StarCluster commands
      - starcluster.commands.createkey.CmdCreateKey: createkey [options] <name>
      - starcluster.commands.createvolume.CmdCreateVolume: createvolume [options] <volume_size> <volume_zone>
        - starcluster.commands.resizevolume.CmdResizeVolume: resizevolume [options] <volume_id> <volume_size>
      - starcluster.commands.help.CmdHelp: help
      - starcluster.commands.listbuckets.CmdListBuckets: listbuckets
      - starcluster.commands.listimages.CmdListImages: listimages [options]
      - starcluster.commands.listinstances.CmdListInstances: listinstances [options]
      - starcluster.commands.listkeypairs.CmdListKeyPairs: listkeypairs
      - starcluster.commands.listpublic.CmdListPublic: listpublic
      - starcluster.commands.listregions.CmdListRegions: listregions
      - starcluster.commands.listspots.CmdListSpots: listspots
      - starcluster.commands.listvolumes.CmdListVolumes: listvolumes
      - starcluster.commands.listzones.CmdListZones: listzones
      - starcluster.commands.removekey.CmdRemoveKey: removekey [options] <name>
      - starcluster.commands.runplugin.CmdRunPlugin: runplugin <plugin_name> <cluster_tag>
      - starcluster.commands.shell.CmdShell: shell
      - starcluster.commands.showbucket.CmdShowBucket: showbucket <bucket>
      - starcluster.commands.spothistory.CmdSpotHistory: spothistory [options] <instance_type>
      - starcluster.commands.completers.Completer: Base class for all completer classes
        - starcluster.commands.completers.ClusterCompleter: Returns a list of all cluster names as completion options
          - starcluster.commands.addnode.CmdAddNode: addnode [options] <cluster_tag>
          - starcluster.commands.listclusters.CmdListClusters: listclusters [<cluster_tag> ...]
          - starcluster.commands.loadbalance.CmdLoadBalance: loadbalance <cluster_tag>
          - starcluster.commands.removenode.CmdRemoveNode: removenode [options] <cluster_tag> <node> [<node> ...]
          - starcluster.commands.restart.CmdRestart: restart [options] <cluster_tag>
          - starcluster.commands.sshmaster.CmdSshMaster: sshmaster [options] <cluster>
          - starcluster.commands.start.CmdStart: start [options] <cluster_tag>
          - starcluster.commands.stop.CmdStop: stop [options] <cluster_tag> ...
          - starcluster.commands.terminate.CmdTerminate: terminate [options] <cluster_tag> ...
        - starcluster.commands.completers.ImageCompleter: Returns a list of all registered image ids as completion options
          - starcluster.commands.downloadimage.CmdDownloadImage: downloadimage [options] <image_id> <destination_directory>
            - starcluster.commands.showimage.CmdShowImage: showimage <image_id>
          - starcluster.commands.removeimage.CmdRemoveImage: removeami [options] <imageid>
        - starcluster.commands.completers.InstanceCompleter: Returns a list of all instance ids as completion options
          - starcluster.commands.ebsimage.CmdEbsImage: ebsimage [options] <instance-id> <image_name>
          - starcluster.commands.s3image.CmdS3Image: s3image [options] <instance-id> <image_name> [<bucket>]
          - starcluster.commands.showconsole.CmdShowConsole: showconsole <instance-id>
          - starcluster.commands.sshinstance.CmdSshInstance: sshinstance [options] <instance-id>
        - starcluster.commands.completers.NodeCompleter: Returns a list of all node names as completion options
          - starcluster.commands.sshnode.CmdSshNode: sshnode <cluster> <node>
        - starcluster.commands.completers.VolumeCompleter: Returns a list of all volume ids as completion options
          - starcluster.commands.removevolume.CmdRemoveVolume: removevolume [options] <volume_id>
  - starcluster.optcomplete.DirCompleter: Completes by listing subdirectories only.
  - starcluster.awsutils.EasyAWS
    - starcluster.awsutils.EasyEC2
    - starcluster.awsutils.EasyS3
  - starcluster.image.ImageCreator: Base class for S3/EBS Image Creators.
    - starcluster.image.EBSImageCreator: Creates a new EBS image from a running instance
    - starcluster.image.S3ImageCreator: Class for creating a new instance-store AMI from a running instance
  - starcluster.iptools.IpRange: Range of ip addresses.
  - starcluster.iptools.IpRangeList: List of IpRange objects.
  - workerpool.jobs.Job: Interface for a Job object.
    - workerpool.jobs.SimpleJob: Given a `result` queue, a `method` pointer, and an `args` dictionary or list, the method will execute r = method(*args) or r = method(**args), depending on args' type, and perform result.put(r).
      - starcluster.threadpool.SimpleJob
  - starcluster.optcomplete.ListCompleter: Completes by filtering using a fixed list of strings.
  - starcluster.balancers.LoadBalancer: Base class for all load balancers
    - starcluster.balancers.sge.SGELoadBalancer: This class is able to query each SGE host and return load & queue statistics
  - starcluster.managers.Manager: Base class for all Manager classes in StarCluster
    - starcluster.cluster.ClusterManager: Manager class for Cluster objects
    - starcluster.node.NodeManager: Manager class for Node objects
  - starcluster.node.Node: This class represents a single compute node in a StarCluster.
  - starcluster.optcomplete.NoneCompleter: Generates empty completion list.
  - starcluster.progressbar.ProgressBar: This is the ProgressBar class, it updates and prints the bar.
  - starcluster.progressbar.ProgressBarWidget: This is an element of ProgressBar formatting.
    - starcluster.progressbar.ETA: Widget for the Estimated Time of Arrival
    - starcluster.progressbar.FileTransferSpeed: Widget for showing the transfer speed (useful for file transfers).
    - starcluster.progressbar.Fraction: Just the fraction done.
    - starcluster.progressbar.Percentage: Just the percentage done.
    - starcluster.progressbar.RotatingMarker: A rotating marker for filling the bar of progress.
  - starcluster.progressbar.ProgressBarWidgetHFill: This is a variable width element of ProgressBar formatting.
    - starcluster.progressbar.Bar: The bar of progress.
      - starcluster.progressbar.ReverseBar: The reverse bar of progress, or bar of regress.
  - starcluster.optcomplete.RegexCompleter: Completes by filtering all possible files with the given list of regexps.
  - starcluster.balancers.sge.SGEStats: SunGridEngine stats parser
  - starcluster.balancers.sge.visualizer.SGEVisualizer: Stats Visualizer for SGE Load Balancer stats_file - file containing SGE load balancer stats pngpath - directory to dump the stat plots to
  - starcluster.ssh.SSHClient: Establishes an SSH connection to a remote host using either password or private key authentication.
  - starcluster.cli.StarClusterCLI: StarCluster Command Line Interface
  - starcluster.config.StarClusterConfig: Loads StarCluster configuration settings defined in config_file which defaults to ~/.starclustercfg
  - unittest.TestCase: A class whose instances are single test cases.
    - starcluster.tests.StarClusterTest
      - starcluster.tests.test_cluster_validation.TestClusterValidation
      - starcluster.tests.test_sge_balancer.TestSGELoadBalancer
      - starcluster.tests.test_config.TestStarClusterConfig
  - threading._Verbose
    - threading.Thread
      - starcluster.spinner.Spinner
      - workerpool.workers.Worker: A loyal worker who will pull jobs from the `jobs` queue and perform them.
        - starcluster.threadpool.DaemonWorker: Improved Worker that sets daemon = True by default and also handles communicating exceptions to the parent pool object by adding them to the parent pool's exception queue
  - dict: dict() -> new empty dictionary dict(mapping) -> new dictionary initialized from a mapping object's (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list.
    - starcluster.utils.AttributeDict: Subclass of dict that allows read-only attribute-like access to dictionary key/values